@@ -25,7 +25,7 @@ from calculate.lib.utils.files import (getProgPath, pathJoin, process, STDOUT,
                                        readFile, writeFile, listDirectory)
 
 _ = lambda x: x
-setLocalTranslate('cl_ldap3', sys.modules[__name__])
+setLocalTranslate('cl_lib3', sys.modules[__name__])
 
 
 class backgrounds(TemplateFormat):
@@ -66,7 +66,7 @@ class backgrounds(TemplateFormat):
     def _create_image(self, source, target, width, height, force=False):
         res = "%dx%d" % (width, height)
         if not force and (
-                width > self.source_width or height > self.source_height):
+                        width > self.source_width or height > self.source_height):
             return False
         convert = process(self.convert_cmd, "-quality", "95",
                           source, "-resize", "%s^" % res,
@@ -123,34 +123,40 @@ class backgrounds(TemplateFormat):
             self.setError(_("Failed to detect resolution for image '%s'") %
                           source)
             return False
-        removed_files = []
-        extensions = self.objVar.Get('cl_image_formats')
-        re_remove = re.compile(r"^.*\d{3,4}x\d{3,4}\.(%s)$"
-                               % "|".join(extensions))
-        for remove_fn in listDirectory(workdir, fullPath=True):
-            fn = os.path.split(remove_fn)[1]
-            if re_remove.match(fn):
-                removed_files.append(remove_fn)
         if self.text.strip():
             text_list = self.text.split("\n")
         else:
             text_list = self.objVar.Get('cl_resolutions')
-        self.changed_files.append(md5_fn)
         image_files = []
-        for line in (x for x in text_list if not x.startswith("#")):
-            line = line.strip()
-            if not line:
-                continue
-            rule_match = reRule.search(line)
+        resolutions = [x.strip() for x in text_list
+                       if not x.startswith("#") and x.strip()]
+        only_one = len(resolutions) == 1
+        if only_one:
+            removed_files = [pathJoin(workdir, prefix)]
+        else:
+            removed_files = []
+            extensions = self.objVar.Get('cl_image_formats')
+            re_remove = re.compile(r"^.*\d{3,4}x\d{3,4}\.(%s)$"
+                                   % "|".join(extensions))
+            for remove_fn in listDirectory(workdir, fullPath=True):
+                fn = os.path.split(remove_fn)[1]
+                if re_remove.match(fn):
+                    removed_files.append(remove_fn)
+        for resolution in resolutions:
+            rule_match = reRule.search(resolution)
             if not rule_match:
-                self.setError(_("Wrong 'backgrounds' resolution: %s") % line)
+                self.setError(
+                    _("Wrong 'backgrounds' resolution: %s") % resolution)
                 return False
             width, height = rule_match.groups()
             width = int(width)
             height = int(height)
 
-            image_fn = pathJoin(workdir,
-                                "%s%s.%s" % (prefix, line, self.convert))
+            if only_one:
+                image_fn = pathJoin(workdir, prefix)
+            else:
+                image_fn = pathJoin(workdir, "%s%s.%s" % (
+                    prefix, resolution, self.convert))
             if self._create_image(source, image_fn, width, height,
                                   force=self.stretch):
                 if image_fn in removed_files:
@@ -158,10 +164,12 @@ class backgrounds(TemplateFormat):
                 image_files.append(image_fn)
             else:
                 self.parent.printWARNING(
-                    _("Failed to create image with %s resolution") % (
+                    _("Skipped creation of the image with %s resolution") % (
                         "%dx%d" % (width, height)))
-        with writeFile(md5_fn) as f:
-            f.write("%s\n" % image_md5)
+        if not only_one:
+            with writeFile(md5_fn) as f:
+                f.write("%s\n" % image_md5)
+            self.changed_files.append(md5_fn)
         for remove_fn in removed_files:
             try:
                 if os.path.lexists(remove_fn):
